﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

using Infragistics.Controls.Menus;
using Infragistics.Controls.Grids;

using Dialogs;

namespace TreeSelectionProblem_ig_10_2
{
    public partial class MainPage : UserControl
    {
        private List<Person> _peopleCollection = null;
        private XamTreeItem _prevTreeItemHardCodedLeaf3 = null;

        // this flag is to prevent the treeview's initial selectionchanged from processing
        private bool _bInitializing = true;
        
        // this flag is to prevent an infinite loop
        private bool _bChanging = false;
        public MainPage()
        {            
            InitializeComponent();

            // grid row selection settings (read-only selection grid [so select entire row when clicking anywhere])
            igGridTransactions.SelectionSettings.ColumnSelection = SelectionType.None;
            igGridTransactions.SelectionSettings.RowSelection = SelectionType.Multiple;
            igGridTransactions.SelectionSettings.CellSelection = SelectionType.None;
            igGridTransactions.SelectionSettings.CellClickAction = CellSelectionAction.SelectRow;

            _peopleCollection = new List<Person>();

            this.LoadPeople();
            this.LoadTree();

            igGridTransactions.ItemsSource = _peopleCollection;            
        }        

        private void LoadPeople()
        {
            _peopleCollection.Clear();

            _peopleCollection.Add(new Person() { First = "Ken", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Don", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Jeff", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "William", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Tim", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Colleen", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Tom", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Monica", Last = "Smith" });
        }

        private void LoadTree()
        {
            XamTree igTreeTransactions = obFolderControl.Groups["Group1"].Content as XamTree;

            igTreeTransactions.Items.Clear();

            XamTreeItem rootItem = new XamTreeItem() { Header = "Root", IsExpanded = true };

            XamTreeItem parentItem1 = new XamTreeItem() { Header = "Parent 1", IsExpanded = true };

            XamTreeItem leafItem1 = new XamTreeItem() { Header = "Leaf 1", IsExpanded = true };            

            XamTreeItem leafItem2 = new XamTreeItem() { Header = "Leaf 2", IsExpanded = true };
            

            XamTreeItem leafItem3 = new XamTreeItem() { Header = "Leaf 3", IsExpanded = true };
            leafItem3.IsSelected = true;

            // Hard-coded
            _prevTreeItemHardCodedLeaf3 = leafItem3;

            parentItem1.Items.Add(leafItem1);
            parentItem1.Items.Add(leafItem2);
            parentItem1.Items.Add(leafItem3);

            rootItem.Items.Add(parentItem1);

            igTreeTransactions.Items.Add(rootItem);
        }

        private void igTree_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if ((!_bChanging) && (!_bInitializing))
            {
                _bChanging = true;

                TcMessageWindow.Show("Please click CANCEL to see the problem", "Playground App", 
                    TcMessageWindowButton.OKCancel, TcMessageWindowIcon.Warning, OnChildWindowClosed);                                
            }

            _bInitializing = false;
        }

        private void OnChildWindowClosed(object sender, EventArgs e)
        {

            if (TcMessageWindow.Result == MessageBoxResult.Cancel)
            {
                // grab the tree
                XamTree tree = obFolderControl.Groups["Group1"].Content as XamTree;

                // remove currently selected item
                tree.SelectedItems.Clear();

                // change back to previously selected node which is hardcoded to leaf 3
                tree.SelectedItems.Add(_prevTreeItemHardCodedLeaf3);

                // ??????? HELP!!!!
                //VisualStateManager.GoToState(_prevSelection, "UnFocused", true);
            }
            _bChanging = false;
        }
    }

    public class Person
    {
        public string First { get; set; }
        public string Last { get; set; }

        public Person()
        {

        }

        public Person(string sFirst, string sLast)
        {
            First = sFirst;
            Last = sLast;
        }
    }
}
